@@ -6,14 +6,16 @@ class ARRAY(types.ARRAY):
         super().__init__(item_type)
 
     def get_col_spec(self, **kw):
-        return "Type(%s)" % self.type
+        return "Type(%s)" % self.item_type
 
     def bind_processor(self, dialect):
         def process(value):
             return value
+
         return process
 
     def result_processor(self, dialect, coltype):
         def process(value):
             return value
+
         return process
