@@ -1,10 +1,9 @@
-import os
-import json
 from requests import Session
+
 from .steps import TestSteps
 
-class TestDBCreation:
 
+class TestDBCreation:
     def test_db_creation(self, settings):
         test_steps = TestSteps(settings)
         session = Session()
